pub struct Semaphore(/* private fields */);Implementations
Sourceimpl Semaphore
impl Semaphore
pub fn new(parallelism: NonZeroU32) -> Self
Sourcepub fn acquire_rayon(&self, panic_if_not_rayon: bool) -> SemaphoreHolder<'_>
pub fn acquire_rayon(&self, panic_if_not_rayon: bool) -> SemaphoreHolder<'_>
Meant to be run from a thread in a rayon thread pool, so that
it can efficiently yield to other rayon work. If you give
panic_if_not_rayon == true then it will panic if this is not
the case.
Sourcepub fn acquire_os(&self) -> SemaphoreHolder<'_>
pub fn acquire_os(&self) -> SemaphoreHolder<'_>
Not efficient, yields to the OS on each failure, and without blocking!